@@ -17,3 +17,13 @@ class Font:
             return 0
 
         return self.bdf_font.glyphbycp(char).meta['dwx0']
+
+    @property
+    def height(self):
+        if self.bdf_font is None: return -1
+        return self.headers['fbby']
+
+    @property
+    def baseline(self):
+        if self.bdf_font is None: return 0
+        return self.headers['fbby'] + self.headers['fbbyoff']
